<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://sharabindu.com
 * @since      1.2.1
 *
 * @package    product-barcode-generator
 * @subpackage product-barcode-generator/admin
 */
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    product-barcode-generator
 * @subpackage product-barcode-generator/admin
 * @author     Sharabindu Bakshi <sharabindu86@gmail.com>
 */
class pbar_generator_Admin
{

    /**
     * The option page variable of this plugin.
     *
     * @since    1.2.1
     * @access   private
     * @var      string
     $qrc_option_page_options     option name.
     */
    private $qrc_option_page_options;

    /**
     * The ID of this plugin.
     *
     * @since    1.2.1
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.2.1
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.2.1
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class_pbarcode_genartor.php';

        $plugin_name = new Pbarcode_Generator();

    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.2.1
     */
    public function enqueue_styles()
    {
        wp_enqueue_style('wp-color-picker');

        wp_enqueue_style($this->plugin_name, PBARGENERATOR_URL . 'admin/css/pbar_generator-admin.css', array() , $this->version, 'all');

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.2.1
     */
    public function enqueue_scripts()
    {

        wp_enqueue_script('wp-color-picker');

        wp_enqueue_script('JsBarcode', PBARGENERATOR_URL . 'admin/js/JsBarcode.all.min.js', array(
            'jquery'
        ) , $this->version, false);

        wp_enqueue_script('bbq', PBARGENERATOR_URL . 'admin/js/jquery.bbq.min.js', array('jquery') , $this->version, false);

        wp_enqueue_script('print_option', PBARGENERATOR_URL . 'admin/js/jQuery.print.js', array() , $this->version, true);

        wp_enqueue_script('download', PBARGENERATOR_URL . 'admin/js/download.js', array() , $this->version, true);


        wp_enqueue_script('pbrcode-generator-admin', PBARGENERATOR_URL . 'admin/js/pbrcode-generator-admin.js', array('jquery','wp-color-picker','bbq') , $this->version, true);
        
     

    }

    /**
     * Setting link.
     *
     * @since    1.2.1
     */

    public function plugin_settings_link($links)
    {
        if (is_admin())
        {

            return array_merge(array(
                '<a href="' . admin_url('admin.php?page=pbar_print') . '">' . esc_html__('Settings', 'product-barcode-generator') . '</a>',
            ) , $links);
        }
    }

    /**
     * This function is Add Menu page call back function.
     */

    public function admin_menu_define()
    {

        $icon_url = PBARGENERATOR_URL . 'admin/img/admin.png';

        add_menu_page(esc_html__('Barcode GEN.', 'product-barcode-generator') , esc_html__('Barcode GEN.', 'product-barcode-generator') , 'manage_options', 'pbar_print', array(
            $this,
            'pbarcode_print_pdf'
        ) , $icon_url);

    }

    function pbarcode_print_pdf()
    {

        $this->pbarginerator_print_options = get_option('pbarginerator_print_option');


?>


             <div class="pbar_wrap">
                 <div class="pbar_wp_admin">
                    <ul class="pbar_nav_bar_code">
                        <li><a href="https://masterqr.sharabindu.com/product-barcode-generator/" target="_blank"><?php echo esc_html('Demo Page', 'product-barcode-generator') ?></a></li>
                        <li><a href="http://docs-barcode.sharabindu.com/index.html" target="_blank"><?php echo esc_html('Docs', 'product-barcode-generator') ?></a></li>

                        <li><a href="https://sharabindu.com/contact-us/" target="_blank"><?php echo esc_html('Contact Us', 'product-barcode-generator') ?></a></li>

                        <li><a href="https://sharabindu.com/plugins/" target="_blank"><?php echo esc_html('More Plugin', 'product-barcode-generator') ?></a></li>

                        <li><a href="https://sharabindu.com/plugins/product-barcode-generator/" target="_blank"><?php echo esc_html('Get Premium Licence', 'product-barcode-generator') ?></a></li>
                    </ul>
                     <ul  class="pbar_hdaer_cnt">
                         <li> <img src=" <?php echo PBARGENERATOR_URL . '/admin/img/loh.png' ?>" alt="qr logo"></li>

                             <li  class="pbar_fd_cnt"> 
                                 <h3><?php echo esc_html('Product Barcode Generator', 'product-barcode-generator')  . ' ' . PBARGENERATOR_VERSION;?> </h3>
                         <small><?php echo esc_html('Generate barcodes in an easy way', 'product-barcode-generator') ?></small></li>
                     </ul>

                 </div>


                 <div class="pbar_dashboard_wrap">
                         <div>

                 <ul class="pbarcode_tbs_admn at-tabs-when-possible bbq clearfix at-accordion-or-tabs at-tabs ">
                   <li><a><?php echo esc_html("Barcode Settings ","product-barcode-generator") ?></a>
                    <section>
                    <div class="pbar_wrap-md-8">
                    <form method="post" action="options.php">
                    <?php
                    if(!class_exists("WooCommerce")){
                    echo "<p class='wcplugin_active'>Please enable the WooCommerce plugin, the barcode generator will not work without 'WooCommerce'</p>";
                    }

                    settings_errors();
                    settings_fields("pbarginerator_print_option");

                    do_settings_sections('pbarcode_print_setting');

                    submit_button();

                   ?>  

                    </form>
                    </div>  

                    <div class="pbar_wrap-md-4">
                    <div style="float: none; clear: both;">
                    <div class="pbar_freeftcs_cont">
                    <h4 class="pbar_ftcs__h"><?php echo esc_html__(' How it Works', 'product-barcode-generator') ?></h4>

                    <div>

                    <div class="parccintr"><?php echo esc_html__('After saving this settings, go to','product-barcode-generator');?> <span class="dashicons-before dashicons-archive"></span><?php echo esc_html__('Products, then All Products, and then Edit a Product. Scroll down, you will find the "Product Barcode" section', 'product-barcode-generator'); ?>
                    </div>                       
                    <p><img style="width:100%;padding:0" src=" <?php echo PBARGENERATOR_URL . '/admin/img/free-barcode.png' ?>" alt="Demo barcode"></p>

                    </div>

                    </div>
                    <div class="pbar_freeftcs_cont">
                    <h4 class="pbar_ftcs__h"><?php echo esc_html__(' Why Upgrade to Premium', 'product-barcode-generator') ?></h4>

                    <div>

   <ul><li><?php echo esc_html__('Barcode height change', 'product-barcode-generator') ?></li>
   <ul><li><?php echo esc_html__('Barcode Color change', 'product-barcode-generator') ?></li>
      <li><?php echo esc_html__('Background Background change', 'product-barcode-generator') ?></li>
       <li><?php echo esc_html__('Bulk Print from Dashboard', 'product-barcode-generator') ?></li>
       <li><?php echo esc_html__(' Download the barcode as a list', 'product-barcode-generator') ?></li>
       <li><?php echo esc_html__('Add Capabily(User Role) facility', 'product-barcode-generator') ?></li>
       <li><?php echo esc_html__('Shortcode for Print the Barcode ', 'product-barcode-generator') ?></li>
       <li><?php echo esc_html__('Shortcode for Download the Barcode ', 'product-barcode-generator') ?></li>
       <li><?php echo esc_html__('Premium support & Many more', 'product-barcode-generator') ?></li>
       <em><a href="https://sharabindu.com/plugins/product-barcode-generator/#pricing"> View Pricing</a></em>
   
   </ul>                      
                    <p><img style="width:100%;padding:0" src=" <?php echo PBARGENERATOR_URL . '/admin/img/sdsdsdsds-min.png' ?>" alt="Demo barcode"></p>
                    <a class="pbar_gtnow" href="https://sharabindu.com/plugins/product-barcode-generator/"><?php echo esc_html__('Get Premium', 'product-barcode-generator') ?></a>
                    </div>

                    </div>
                    </div>
                    </div> 
                     </section>
                   </li>
                   <li>
                    <a><?php echo esc_html("Print Page (PRO)","product-barcode-generator") ?></a>
                <section>
                <div id="pbarcode_print_page">
                <img src=" <?php echo PBARGENERATOR_URL . '/admin/img/print-min.png' ?>" alt="Demo barcode">

                </div>  
                </section>
                   </li>

                      <li>
                       <a><?php echo esc_html("Download Page(PRO)","product-barcode-generator") ?></a>
                   <section>
                   <div id="pbarcode_print_page">
                   <img src=" <?php echo PBARGENERATOR_URL . '/admin/img/download-new.png' ?>" alt="Demo barcode">

                   </div>  
                   </section>
                      </li>
                 </ul>
</div>
</div>

        <?php
    }

    

}

